@@ -272,8 +272,27 @@ class ClickReview(Review):
             if len(self.manifest['hooks'][app]) < 1:
                 error("manifest malformed: hooks/%s is empty:\n%s" % (app, mp))
 
+        # optional migrations
+        if 'migrations' in self.manifest:
+            if not isinstance(self.manifest['migrations'], dict):
+                error("manifest malformed: 'migrations' is not dict:\n%s" % mp)
+            if len(self.manifest['migrations']) < 1:
+                error("manifest malformed: 'migrations' is empty:\n%s" % mp)
+            for k in self.manifest['migrations'].keys():
+                if k not in {'old-name'}:
+                    error(
+                        "manifest malformed: unsupported field "
+                        "'migrations/%s':\n%s" % (k, mp)
+                    )
+            if 'old-name' in self.manifest['migrations']:
+                if not isinstance(self.manifest['migrations']['old-name'], str):
+                    error(
+                        "manifest malformed: migrations/old-name is not"
+                        "str:\n%s" % mp
+                    )
+
         for k in sorted(self.manifest):
-            if k not in required + optional + snappy_optional + ['hooks']:
+            if k not in required + optional + snappy_optional + ['hooks', 'migrations']:
                 # click supports local extensions via 'x-...', ignore those
                 # here but report in lint
                 if k.startswith('x-'):
