@@ -28,6 +28,8 @@ from xdg.Exceptions import ParsingError as xdgParsingError
 
 class ClickReviewDesktop(ClickReview):
     '''This class represents click lint reviews'''
+    supported_versions = ("1.0", "1.1", "1.2", "1.3", "1.4", "1.5")
+
     def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         my_hook = 'desktop'
@@ -62,8 +64,9 @@ class ClickReviewDesktop(ClickReview):
                               'Type',
                               'Icon',
                               'Exec',
-                              'X-Ubuntu-Touch',
+                              'X-Lomiri-Touch',
                               ]
+        self.key_alt = {'X-Lomiri-Touch': 'X-Ubuntu-Touch'}
         self.expected_execs = ['qmlscene',
                                'webbrowser-app',
                                'webapp-container',
@@ -144,7 +147,8 @@ class ClickReviewDesktop(ClickReview):
             except Exception as e:
                 t = 'error'
                 s = 'did not validate: (%s)' % str(e)
-                link = 'http://askubuntu.com/questions/417377/what-does-desktop-validates-mean/417378'
+                link = ('http://askubuntu.com/questions/417377/'
+                        'what-does-desktop-validates-mean/417378')
             self._add_result(t, n, s, link)
 
     def check_desktop_required_keys(self):
@@ -160,7 +164,9 @@ class ClickReviewDesktop(ClickReview):
             missing = []
             for f in self.required_keys:
                 if not de.hasKey(f):
-                    missing.append(f)
+                    alt = self.key_alt.get(f, None)
+                    if not (alt and de.hasKey(alt)):
+                        missing.append(f)
             if len(missing) > 0:
                 t = 'error'
                 s = 'missing required keys: %s' % ",".join(missing)
@@ -215,15 +221,17 @@ class ClickReviewDesktop(ClickReview):
                 t = 'error'
                 s = "absolute path '%s' for Exec given in .desktop file." % \
                     de.getExec()
-                link = 'http://askubuntu.com/questions/417381/what-does-desktop-exec-mean/417382'
+                link = ('http://askubuntu.com/questions/417381/'
+                        'what-does-desktop-exec-mean/417382')
             elif de.getExec().split()[0] not in self.expected_execs:
                 if self.pkg_arch[0] == "all":  # interpreted file
+                    template = "found %s Exec with architecture '%s': %s"
                     if de.getExec().split()[0] not in self.deprecated_execs:
-                        s = "found unexpected Exec with architecture '%s': %s" % \
-                            (self.pkg_arch[0], de.getExec().split()[0])
+                        verb = 'unexpected'
                     else:
-                        s = "found deprecated Exec with architecture '%s': %s" % \
-                            (self.pkg_arch[0], de.getExec().split()[0])
+                        verb = 'deprecated'
+                    s = template % \
+                        (verb, self.pkg_arch[0], de.getExec().split()[0])
                     t = 'warn'
                 else:                        # compiled
                     # TODO: this can be a lot smarter
@@ -350,7 +358,8 @@ class ClickReviewDesktop(ClickReview):
                 continue
 
             t = 'info'
-            n = self._get_check_name('Exec_webapp_args_minimal_chrome', app=app)
+            n = self._get_check_name('Exec_webapp_args_minimal_chrome',
+                                     app=app)
             s = 'OK'
             if '--enable-back-forward' not in de.getExec().split():
                 s = "could not find --enable-back-forward in '%s'" % \
@@ -389,10 +398,10 @@ class ClickReviewDesktop(ClickReview):
             if is_launching_local_app and \
                     (found_url_patterns or found_model_search_path or
                      found_named_webapp):
-                    t = 'error'
-                    s = "should not specify --webappUrlPatterns, " + \
-                        "--webappModelSearchPath or --webapp= when " + \
-                        "running local application"
+                t = 'error'
+                s = "should not specify --webappUrlPatterns, " + \
+                    "--webappModelSearchPath or --webapp= when " + \
+                    "running local application"
             elif not is_launching_local_app:
                 if not found_url_patterns and not found_model_search_path:
                     t = 'error'
@@ -404,7 +413,7 @@ class ClickReviewDesktop(ClickReview):
         pattern_count = 1
         for pattern in patterns:
             urlp_scheme_pat = pattern[:-1].split(':')[0]
-            urlp_p = urlsplit(re.sub('\?', '', pattern[:-1]))
+            urlp_p = urlsplit(re.sub(r'\?', '', pattern[:-1]))
             target = args[-1]
             urlp_t = urlsplit(target)
 
@@ -703,68 +712,88 @@ class ClickReviewDesktop(ClickReview):
                 s = 'does not use Type=Application'
             self._add_result(t, n, s)
 
-    def check_desktop_x_ubuntu_touch(self):
-        '''Check X-Ubuntu-Touch entry'''
+    def check_desktop_x_lomiri_touch(self):
+        '''Check X-Lomiri-Touch entry'''
         if not self.is_click and not self.is_snap1:
             return
 
         for app in sorted(self.desktop_entries):
             de = self._get_desktop_entry(app)
             t = 'info'
-            n = self._get_check_name('X-Ubuntu-Touch', app=app)
+            n = self._get_check_name('X-Lomiri-Touch', app=app)
             s = "OK"
-            if not de.hasKey('X-Ubuntu-Touch'):
+            if not de.hasKey('X-Lomiri-Touch') and \
+                    not de.hasKey('X-Ubuntu-Touch'):
                 t = 'error'
-                s = "missing key 'X-Ubuntu-Touch'"
-            elif de.get("X-Ubuntu-Touch") != "true" and \
-                    de.get("X-Ubuntu-Touch") != "True":
-                t = 'error'
-                s = 'does not use X-Ubuntu-Touch=true'
+                s = "missing key 'X-Lomiri-Touch'"
+            else:
+                if de.hasKey('X-Lomiri-Touch'):
+                    value = de.get("X-Lomiri-Touch")
+                else:
+                    value = de.get("X-Ubuntu-Touch")
+
+                if value != "true" and value != "True":
+                    t = 'error'
+                    s = 'does not use X-Lomiri-Touch=true'
             self._add_result(t, n, s)
 
-    def check_desktop_x_ubuntu_stagehint(self):
-        '''Check X-Ubuntu-StageHint entry'''
+    def check_desktop_x_lomiri_stagehint(self):
+        '''Check X-Lomiri-StageHint entry'''
         if not self.is_click and not self.is_snap1:
             return
 
         for app in sorted(self.desktop_entries):
             de = self._get_desktop_entry(app)
             t = 'info'
-            n = self._get_check_name('X-Ubuntu-StageHint', app=app)
+            n = self._get_check_name('X-Lomiri-StageHint', app=app)
             s = "OK"
-            if not de.hasKey('X-Ubuntu-StageHint'):
+            if not de.hasKey('X-Lomiri-StageHint') and \
+                    not de.hasKey('X-Ubuntu-StageHint'):
                 t = 'info'
                 s = "OK (not specified)"
-            elif de.get("X-Ubuntu-StageHint") != "SideStage":
-                t = 'error'
-                s = "unsupported X-Ubuntu-StageHint=%s " % \
-                    de.get("X-Ubuntu-StageHint") + \
-                    "(should be for example, 'SideStage')"
+            else:
+                if de.hasKey('X-Lomiri-StageHint'):
+                    value = de.get("X-Lomiri-StageHint")
+                else:
+                    value = de.get("X-Ubuntu-StageHint")
+
+                if value != "SideStage":
+                    t = 'error'
+                    s = "unsupported X-Lomiri-StageHint=%s " % \
+                        value + \
+                        "(should be 'SideStage')"
             self._add_result(t, n, s)
 
-    def check_desktop_x_ubuntu_gettext_domain(self):
-        '''Check X-Ubuntu-Gettext-Domain entry'''
+    def check_desktop_x_lomiri_gettext_domain(self):
+        '''Check X-Lomiri-Gettext-Domain entry'''
         if not self.is_click and not self.is_snap1:
             return
 
         for app in sorted(self.desktop_entries):
             de = self._get_desktop_entry(app)
             t = 'info'
-            n = self._get_check_name('X-Ubuntu-Gettext-Domain', app=app)
+            n = self._get_check_name('X-Lomiri-Gettext-Domain', app=app)
             s = "OK"
-            if not de.hasKey('X-Ubuntu-Gettext-Domain'):
+            if not de.hasKey('X-Lomiri-Gettext-Domain') and \
+                    not de.hasKey('X-Ubuntu-Gettext-Domain'):
                 t = 'info'
                 s = "OK (not specified)"
-            elif de.get("X-Ubuntu-Gettext-Domain") == "":
-                t = 'error'
-                s = "X-Ubuntu-Gettext-Domain is empty"
-            elif de.get("X-Ubuntu-Gettext-Domain") != self.click_pkgname:
-                t = 'warn'
-                s = "'%s' != '%s'" % (de.get("X-Ubuntu-Gettext-Domain"),
-                                      self.click_pkgname)
-                s += " (ok if app uses i18n.domain('%s')" % \
-                     de.get("X-Ubuntu-Gettext-Domain") + \
-                     " or uses organizationName"
+            else:
+                if de.hasKey('X-Lomiri-Gettext-Domain'):
+                    value = de.get("X-Lomiri-Gettext-Domain")
+                else:
+                    value = de.get("X-Ubuntu-Gettext-Domain")
+
+                if value == "":
+                    t = 'error'
+                    s = "X-Lomiri-Gettext-Domain is empty"
+                elif value != self.click_pkgname:
+                    t = 'warn'
+                    s = "'%s' != '%s'" % (value,
+                                          self.click_pkgname)
+                    s += " (ok if app uses i18n.domain('%s')" % \
+                         value + \
+                         " or uses organizationName"
             self._add_result(t, n, s)
 
     def check_desktop_terminal(self):
@@ -797,12 +826,13 @@ class ClickReviewDesktop(ClickReview):
             link = None
             if not de.hasKey('Version'):
                 s = "OK (not specified)"
-            elif de.getVersionString() != "1.0":
+            elif de.getVersionString() not in self.supported_versions:
                 # http://standards.freedesktop.org/desktop-entry-spec/latest
                 t = 'error'
-                s = "'%s' does not match freedesktop.org version '1.0'" % \
-                    de.getVersionString()
-                link = 'http://askubuntu.com/questions/419907/what-does-version-mean-in-the-desktop-file/419908'
+                s = "'%s' does not match any freedesktop.org version %s" % \
+                    (de.getVersionString(), self.supported_versions)
+                link = ('http://askubuntu.com/questions/419907/'
+                        'what-does-version-mean-in-the-desktop-file/419908')
             self._add_result(t, n, s, link)
 
     def check_desktop_comment(self):
@@ -820,7 +850,8 @@ class ClickReviewDesktop(ClickReview):
                     de.getComment() == "My project description":
                 t = 'warn'
                 s = "Comment uses SDK boilerplate '%s'" % de.getComment()
-                link = 'http://askubuntu.com/questions/417359/what-does-desktop-comment-boilerplate-mean/417360'
+                link = ('http://askubuntu.com/questions/417359/'
+                        'what-does-desktop-comment-boilerplate-mean/417360')
             self._add_result(t, n, s, link)
 
     def check_desktop_icon(self):
@@ -841,24 +872,27 @@ class ClickReviewDesktop(ClickReview):
             if not de.hasKey('Icon'):
                 t = 'error'
                 s = "missing key 'Icon'"
-                link = 'http://askubuntu.com/questions/417369/what-does-desktop-icon-mean/417370'
+                link = ('http://askubuntu.com/questions/417369/'
+                        'what-does-desktop-icon-mean/417370')
             elif de.getIcon().startswith('/'):
                 t = 'error'
                 s = "absolute path '%s' for icon given in .desktop file." % \
                     de.getIcon()
-                link = 'http://askubuntu.com/questions/417369/what-does-desktop-icon-mean/417370'
+                link = ('http://askubuntu.com/questions/417369/'
+                        'what-does-desktop-icon-mean/417370')
             elif not os.path.exists(os.path.join(self.unpack_dir,
                                                  de.getIcon())) and \
-                    True not in filter(lambda a:
-                                       os.path.exists(os.path.join(
-                                                      self.unpack_dir,
-                                                      de.getIcon() + a)),
-                                       ICON_SUFFIXES):
+                    not any(map(lambda a:
+                                os.path.exists(os.path.join(
+                                               self.unpack_dir,
+                                               de.getIcon() + a)),
+                                ICON_SUFFIXES)):
                 t = 'error'
                 s = "'%s' specified as icon in .desktop file for app '%s', " \
                     "which is not available in the click package." % \
                     (de.getIcon(), app)
-                link = 'http://askubuntu.com/questions/417369/what-does-desktop-icon-mean/417370'
+                link = ('http://askubuntu.com/questions/417369/'
+                        'what-does-desktop-icon-mean/417370')
             self._add_result(t, n, s, link)
 
     def check_desktop_duplicate_entries(self):
