@@ -138,3 +138,23 @@ class ClickReviewTestCase(cr_tests.TestClickReview):
 
     def test_check_if_message_catalog_false(self):
         self.assertFalse(self.review._check_if_message_catalog('/a/b/foo.txt'))
+
+    def test_empty_migrations(self):
+        self.review.manifest['migrations'] = {}
+        with self.assertRaises(SystemExit):
+            self.review._verify_manifest_structure()
+
+    def test_invalid_migrations_type(self):
+        self.review.manifest['migrations'] = []
+        with self.assertRaises(SystemExit):
+            self.review._verify_manifest_structure()
+
+    def test_unknown_migrations_value(self):
+        self.review.manifest['migrations'] = {'foo': 'bar'}
+        with self.assertRaises(SystemExit):
+            self.review._verify_manifest_structure()
+
+    def test_invalid_migrations_old_name_type(self):
+        self.review.manifest['migrations'] = {'old-name': 42}
+        with self.assertRaises(SystemExit):
+            self.review._verify_manifest_structure()
