@@ -77,6 +77,26 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_desktop_latest_version(self):
+        '''Test check_desktop_version()'''
+        c = ClickReviewDesktop(self.test_name)
+        self.set_test_desktop(self.default_appname,
+                              "Version", "1.5")
+        c.check_desktop_version()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_desktop_unsupported_version(self):
+        '''Test check_desktop_version() - unsupported Version'''
+        c = ClickReviewDesktop(self.test_name)
+        self.set_test_desktop(self.default_appname,
+                              "Version", "2.0")
+        c.check_desktop_version()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
     def test_check_desktop_file_valid_empty_name(self):
         '''Test check_desktop_file_valid() - empty Name'''
         c = ClickReviewDesktop(self.test_name)
@@ -105,44 +125,44 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    def test_check_desktop_x_ubuntu_gettext_domain_missing(self):
-        '''Test check_desktop_x_ubuntu_gettext_domain when missing'''
+    def test_check_desktop_x_lomiri_gettext_domain_missing(self):
+        '''Test check_desktop_x_lomiri_gettext_domain when missing'''
         c = ClickReviewDesktop(self.test_name)
         self.set_test_desktop(self.default_appname,
-                              "X-Ubuntu-Gettext-Domain", None)
-        c.check_desktop_x_ubuntu_gettext_domain()
+                              "X-Lomiri-Gettext-Domain", None)
+        c.check_desktop_x_lomiri_gettext_domain()
         r = c.click_report
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_check_desktop_x_ubuntu_gettext_domain_empty(self):
-        '''Test check_desktop_x_ubuntu_gettext_domain when empty'''
+    def test_check_desktop_x_lomiri_gettext_domain_empty(self):
+        '''Test check_desktop_x_lomiri_gettext_domain when empty'''
         c = ClickReviewDesktop(self.test_name)
         self.set_test_desktop(self.default_appname,
-                              "X-Ubuntu-Gettext-Domain", "")
-        c.check_desktop_x_ubuntu_gettext_domain()
+                              "X-Lomiri-Gettext-Domain", "")
+        c.check_desktop_x_lomiri_gettext_domain()
         r = c.click_report
         expected_counts = {'info': 0, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
-    def test_check_desktop_x_ubuntu_gettext_domain_valid(self):
-        '''Test check_desktop_x_ubuntu_gettext_domain valid'''
+    def test_check_desktop_x_lomiri_gettext_domain_valid(self):
+        '''Test check_desktop_x_lomiri_gettext_domain valid'''
         c = ClickReviewDesktop(self.test_name)
         self.set_test_desktop(self.default_appname,
-                              "X-Ubuntu-Gettext-Domain",
+                              "X-Lomiri-Gettext-Domain",
                               self.test_control['Package'])
-        c.check_desktop_x_ubuntu_gettext_domain()
+        c.check_desktop_x_lomiri_gettext_domain()
         r = c.click_report
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_check_desktop_x_ubuntu_gettext_domain_mismatch(self):
-        '''Test check_desktop_x_ubuntu_gettext_domain doesn't match'''
+    def test_check_desktop_x_lomiri_gettext_domain_mismatch(self):
+        '''Test check_desktop_x_lomiri_gettext_domain doesn't match'''
         c = ClickReviewDesktop(self.test_name)
         self.set_test_desktop(self.default_appname,
-                              "X-Ubuntu-Gettext-Domain",
+                              "X-Lomiri-Gettext-Domain",
                               "com.example.mismatch")
-        c.check_desktop_x_ubuntu_gettext_domain()
+        c.check_desktop_x_lomiri_gettext_domain()
         r = c.click_report
         expected_counts = {'info': 0, 'warn': 1, 'error': 0}
         self.check_results(r, expected_counts)
@@ -785,7 +805,8 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
 
     def test_check_desktop_exec_webbrowser_local_pattern(self):
-        '''Test test_check_desktop_exec_webbrowser_local_pattern() invalid pattern'''
+        '''Test test_check_desktop_exec_webbrowser_local_pattern() invalid
+        pattern'''
         c = ClickReviewDesktop(self.test_name)
         ex = "webapp-container " + \
              "--webappUrlPatterns=https?://mobile.twitter.com/* " + \
@@ -799,7 +820,8 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
 
     def test_check_desktop_exec_webbrowser_local_webapp(self):
-        '''Test test_check_desktop_exec_webbrowser_local_webapp() invalid webapp cli'''
+        '''Test test_check_desktop_exec_webbrowser_local_webapp() invalid
+        webapp cli'''
         c = ClickReviewDesktop(self.test_name)
         ex = "webapp-container " + \
              "--webapp=DEADBEEF " + \
@@ -813,7 +835,8 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         self.check_results(r, expected_counts)
 
     def test_check_desktop_exec_webbrowser_local_model(self):
-        '''Test test_check_desktop_exec_webbrowser_local_model() invalid model'''
+        '''Test test_check_desktop_exec_webbrowser_local_model() invalid
+        model'''
         c = ClickReviewDesktop(self.test_name)
         ex = "webapp-container " + \
              "--webappModelSearchPath=. " + \
