@@ -14,9 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from clickreviews.common import (
-    MKSQUASHFS_OPTS
-)
 import json
 import os
 import shutil
@@ -24,32 +21,6 @@ import subprocess
 import tempfile
 
 
-def make_snap2(name='test', pkgfmt_type='snap', pkgfmt_version='16.04',
-               version='1.0', summary="An application", extra_files=None,
-               output_dir=None):
-    '''Return the path to a snap v2 package with the given data.
-
-    Caller is responsible for deleting the output_dir afterwards.
-    '''
-    assert(pkgfmt_type == "snap" and pkgfmt_version != "15.04")
-
-    build_dir = tempfile.mkdtemp()
-
-    try:
-        make_dir_structure(build_dir, pkgfmt_type=pkgfmt_type,
-                           pkgfmt_version=pkgfmt_version,
-                           extra_files=extra_files)
-        write_icon(build_dir)
-        description = summary
-        write_meta_data2(build_dir, name, version, summary, description)
-        pkg_path = build_package(build_dir, name, version, pkgfmt_type,
-                                 pkgfmt_version, output_dir=output_dir)
-    finally:
-        shutil.rmtree(build_dir)
-
-    return pkg_path
-
-
 def make_click(name='test', pkgfmt_type='click', pkgfmt_version='0.4',
                package_types=None, version='1.0', title="An application",
                framework='ubuntu-sdk-15.04', extra_files=None,
@@ -58,8 +29,8 @@ def make_click(name='test', pkgfmt_type='click', pkgfmt_version='0.4',
 
     Caller is responsible for deleting the output_dir afterwards.
     """
-    assert(pkgfmt_type == "click" or (pkgfmt_type == "snap" and
-                                      pkgfmt_version == "15.04"))
+    assert (pkgfmt_type == "click" or (pkgfmt_type == "snap" and
+                                       pkgfmt_version == "15.04"))
 
     is_snap1 = (pkgfmt_type == "snap")
     build_dir = tempfile.mkdtemp()
@@ -285,17 +256,11 @@ def build_package(path, name, version, pkgfmt_type, pkgfmt_version,
     output_dir = output_dir or tempfile.mkdtemp()
     output_path = os.path.join(output_dir, filename)
 
-    if pkgfmt_type == "snap" and pkgfmt_version != "15.04":
-        args = ['mksquashfs', path, output_path] + MKSQUASHFS_OPTS
-        # debugging
-        # subprocess.check_call(args)
-        # subprocess.check_call(['unsquashfs', '-lls', output_path])
-        subprocess.check_call(args, stdout=open(os.devnull, 'w'))
-    else:  # click and snap v1
-        # Note: We're not using 'click build' here as it corrects errors (such
-        # as filtering out a .click directory present in the build). We want
-        # to test with manually constructed, potentially tampered-with
-        # clicks/snaps. Ideally, we'd be using click rather than dpkg to
-        # construct the click without filtering any files in the build dir.
-        subprocess.check_call(['dpkg-deb', '-b', path, output_path])
+    # Note: We're not using 'click build' here as it corrects errors (such
+    # as filtering out a .click directory present in the build). We want
+    # to test with manually constructed, potentially tampered-with
+    # clicks/snaps. Ideally, we'd be using click rather than dpkg to
+    # construct the click without filtering any files in the build dir.
+    subprocess.check_call(['dpkg-deb', '-b', path, output_path])
+
     return output_path
